# Example Notebooks & Google Colab

When using Colab and working on the cuda/GPU examples make sure the Colab Runtime is set to 'GPU'.


|Jupyter Notebook|Colab|Description|
|:---|:---:|:---|
|[standard examples](./notebooks/kmeans.ipynb)|[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/jokofa/torch_kmeans/blob/master/examples/notebooks/kmeans.ipynb)|package introduction and feature demonstration with standard kmeans|
|[constrained kmeans](./notebooks/constrained_kmeans.ipynb)|[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/jokofa/torch_kmeans/blob/master/examples/notebooks/constrained_kmeans.ipynb)|examples of constrained kmeans|
|[soft kmeans](./notebooks/soft_kmeans.ipynb)|[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/jokofa/torch_kmeans/blob/master/examples/notebooks/soft_kmeans.ipynb)|examples of soft kmeans|
|[speed comparison](./notebooks/speed_comparison.ipynb)|[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/jokofa/torch_kmeans/blob/master/examples/notebooks/speed_comparison.ipynb)|Speed comparison of torch_kmeans (CPU, GPU) and scikit-learn KMeans|
